#! /bin/sh
rm -fR \
autom4te.cache \
aclocal.m4 \
config.log \
config.status \
config.guess \
config.sub \
configure \
depcomp \
install-sh \
libtool \
ltmain.sh \
Makefile \
Makefile.in \
missing \
shave \
shave-libtool \
estardict-*.tar.gz \
doc/Makefile \
doc/Makefile.in \
data/Makefile \
data/Makefile.in \
data/images/Makefile \
data/images/Makefile.in \
data/images/crystalClear/Makefile \
data/images/crystalClear/Makefile.in \
data/images/micro/Makefile \
data/images/micro/Makefile.in \
data/images/nuvoX/Makefile \
data/images/nuvoX/Makefile.in \
data/themes/Makefile \
data/themes/Makefile.in \
data/themes/*.edj \
include/config.h \
include/config.h.in \
include/stamp-h1 \
data/resources/Makefile \
data/resources/Makefile.in \
src/Makefile \
src/Makefile.in \
src/engine/Makefile \
src/engine/Makefile.in \
src/engine/*.o \
src/engine/*.la \
src/engine/*.lo \
src/engine/.libs \
src/engine/.deps \
src/gui/Makefile \
src/gui/Makefile.in \
src/gui/estardict \
src/gui/*.o \
src/gui/.libs \
src/tests/Makefile \
src/tests/Makefile.in \
src/tests/estardict_engine_tests \
src/tests/*.o \
src/tests/.libs \
debian/estardict \
.pc \
patches
